@@ -52,7 +52,7 @@ rest of params ---> shexer has multiple configuration params, but maybe just let
 
 """
 
-shape_map_raw = "SPARQL'SELECT DISTINCT ?virus WHERE {   VALUES ?virus {  wd:Q82069695  }  }'@<Virus>  " # wd:Q8351095  wd:Q16983356 wd:Q4902157  wd:Q278567 wd:Q16983360 wd:Q16991954
+shape_map_raw = "SPARQL'select ?x where { ?x wdt:P31 wd:Q95001953 }'@<ResearchSoftware>  " # wd:Q8351095  wd:Q16983356 wd:Q4902157  wd:Q278567 wd:Q16983360 wd:Q16991954
 
 shaper = Shaper(shape_map_raw=shape_map_raw,
                 url_endpoint="https://query.wikidata.org/sparql",
@@ -62,10 +62,14 @@ shaper = Shaper(shape_map_raw=shape_map_raw,
                 keep_less_specific=True,
                 instantiation_property="http://www.wikidata.org/prop/direct/P31",
                 namespaces_dict=namespaces_dict,
-                depth_for_building_subgraph=2,
-                namespaces_for_qualifier_props=["http://www.wikidata.org/prop/"],
-                shape_qualifiers_mode=True,
-                # disable_comments=True,
+                depth_for_building_subgraph=1,
+                # namespaces_for_qualifier_props=["http://www.wikidata.org/prop/"],
+                shape_qualifiers_mode=False,
+                wikidata_annotation=True,
+                disable_comments=True,
+                namespaces_to_ignore=["http://www.wikidata.org/prop/",
+                                      "http://www.w3.org/2004/02/skos/core#",
+                                      "http://www.wikidata.org/prop/direct-normalized"],
                 all_classes_mode=False)
 
 
